@@ -7,33 +7,43 @@ https://developer.github.com/v3/repos/#get
 from datetime import datetime
 
 from aiogithubapi.common.exceptions import AIOGitHubAPIException
-from aiogithubapi.objects.base import AIOGitHubAPIBase
+from aiogithubapi.objects.base import AIOGitHubAPIBaseClient
+from aiogithubapi.objects.repository.traffic import AIOGitHubAPIRepositoryTraffic
+from aiogithubapi.objects.repository.commit import AIOGitHubAPIRepositoryCommit
 
 from aiogithubapi.objects.repository.content import (
     AIOGitHubAPIRepositoryContent,
     AIOGitHubAPIRepositoryTreeContent,
 )
+
 from aiogithubapi.objects.repository.issue import (
     AIOGitHubAPIRepositoryIssue,
     AIOGitHubAPIRepositoryIssueComment,
     AIOGitHubAPIRepositoryIssueCommentUser,
 )
+
 from aiogithubapi.objects.repository.release import AIOGitHubAPIRepositoryRelease
 
+from aiogithubapi.objects.user import AIOGitHubAPIUser
 
-class AIOGitHubAPIRepository(AIOGitHubAPIBase):
+
+class AIOGitHubAPIRepository(AIOGitHubAPIBaseClient):
     """Repository GitHub API implementation."""
 
     def __init__(self, client: "AIOGitHubAPIClient", attributes: dict) -> None:
         """Initialise."""
-        self.client = client
-        self.attributes = attributes
+        super().__init__(client, attributes)
         self._last_commit = None
+        self.traffic = AIOGitHubAPIRepositoryTraffic(client, attributes)
 
     @property
     def id(self) -> None:
         return self.attributes.get("id")
 
+    @property
+    def name(self) -> None:
+        return self.attributes.get("name")
+
     @property
     def full_name(self) -> None:
         return self.attributes.get("full_name")
@@ -58,14 +68,38 @@ class AIOGitHubAPIRepository(AIOGitHubAPIBase):
     def fork(self) -> None:
         return self.attributes.get("fork")
 
+    @property
+    def forks_count(self) -> int:
+        return self.attributes.get("forks_count")
+
     @property
     def default_branch(self) -> None:
         return self.attributes.get("default_branch")
 
+    @property
+    def homepage(self) -> str:
+        return self.attributes.get("homepage")
+
+    @property
+    def stargazers_count(self) -> str:
+        return self.attributes.get("stargazers_count")
+
+    @property
+    def watchers_count(self) -> str:
+        return self.attributes.get("watchers_count")
+
     @property
     def last_commit(self) -> None:
+        if self._last_commit is None:
+            self.logger.warning(
+                "You need to call .set_last_commit to set this property"
+            )
         return self._last_commit
 
+    @property
+    def owner(self) -> AIOGitHubAPIUser:
+        return AIOGitHubAPIUser(self.attributes.get("owner"))
+
     async def get_contents(
         self, path: str, ref: str or None = None
     ) -> ["AIOGitHubAPIRepositoryContent"] or "AIOGitHubAPIRepositoryContent":
@@ -135,6 +169,12 @@ class AIOGitHubAPIRepository(AIOGitHubAPIBase):
         response = await self.client.get(endpoint=_endpoint)
         self._last_commit = response["commit"]["sha"][0:7]
 
+    async def get_last_commit(self) -> None:
+        """Retrun a list of repository release objects."""
+        _endpoint = f"/repos/{self.full_name}/branches/{self.default_branch}"
+        response = await self.client.get(endpoint=_endpoint)
+        return AIOGitHubAPIRepositoryCommit(response)
+
     async def get_issue(self, issue: int) -> "AIOGitHubAPIRepositoryIssue":
         """Updates an issue comment."""
         _endpoint = f"/repos/{self.full_name}/issues/{issue}"
